---
name: Question
about: General questions about usage of glob-linters
title: "[QUESTION]"
labels: question
assignees: ''

---

**Describe your questions, separated as a list if you have multiple questions**
1. Q1
2. Q2
